kbp2video
=========

kbp2video is a GUI for converting .kbp files from Karaoke Builder Studio into video files by converting to Advanced SubStation Alpha subtitles (.ass) as an intermediate format. It uses (and requires) kbp2ass, a CLI utility for converting .kbp to .ass files, and ffmpeg, a multimedia converter.

This program is still in active development and is not yet ready for use. It's only published at this point in case anyone wants to help with development.
